package Parley::View::TT;
# vim: ts=8 sts=4 et sw=4 sr sta
use strict;
use warnings;

use Parley::Version;  our $VERSION = $Parley::VERSION;
use base 'Catalyst::View::TT';

=head1 NAME

Parley::View::TT - Catalyst TT View

=head1 SYNOPSIS

See L<Parley>

=head1 DESCRIPTION

Catalyst TT View.

=head1 AUTHOR

Chisel Wright C<< <chiselwright@users.berlios.de> >>

=head1 LICENSE

This library is free software, you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

1;
